@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     29/10/2000
-## RCS-ID:      $Id: Event.pm 2213 2007-08-25 23:15:15Z mbarbon $
-## Copyright:   (c) 2000-2007 Mattia Barbon
+## RCS-ID:      $Id: Event.pm 2785 2010-02-06 21:31:04Z mdootson $
+## Copyright:   (c) 2000-2010 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -344,6 +344,18 @@ sub EVT_SCROLLWIN_PAGEDOWN($$) { $_[0]->Connect( -1, -1, &Wx::wxEVT_SCROLLWIN_PA
 sub EVT_SCROLLWIN_THUMBTRACK($$) { $_[0]->Connect( -1, -1, &Wx::wxEVT_SCROLLWIN_THUMBTRACK, $_[1] ) }
 sub EVT_SCROLLWIN_THUMBRELEASE($$) { $_[0]->Connect( -1, -1, &Wx::wxEVT_SCROLLWIN_THUMBRELEASE, $_[1] ) }
 
+sub EVT_SCROLLWIN {
+  my( $x, $y ) = @_;
+  EVT_SCROLLWIN_TOP( $x, $y );
+  EVT_SCROLLWIN_BOTTOM( $x, $y );
+  EVT_SCROLLWIN_LINEUP( $x, $y );
+  EVT_SCROLLWIN_LINEDOWN( $x, $y );
+  EVT_SCROLLWIN_PAGEUP( $x, $y );
+  EVT_SCROLLWIN_PAGEDOWN( $x, $y );
+  EVT_SCROLLWIN_THUMBTRACK( $x, $y );
+  EVT_SCROLLWIN_THUMBRELEASE( $x, $y );
+}
+
 #
 # SpinEvent
 #
@@ -361,6 +373,7 @@ sub EVT_SPLITTER_SASH_POS_CHANGING($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_
 sub EVT_SPLITTER_SASH_POS_CHANGED($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_COMMAND_SPLITTER_SASH_POS_CHANGED, $_[2] ) }
 sub EVT_SPLITTER_UNSPLIT($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_COMMAND_SPLITTER_UNSPLIT, $_[2] ) }
 sub EVT_SPLITTER_DOUBLECLICKED($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_COMMAND_SPLITTER_DOUBLECLICKED, $_[2] ) }
+sub EVT_SPLITTER_DCLICK($$$) { $_[0]->Connect( $_[1], -1, &Wx::wxEVT_COMMAND_SPLITTER_DOUBLECLICKED, $_[2] ) }
 
 #
 # SysColourChangedEvent
