@@ -5,8 +5,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     19/08/2007
-## RCS-ID:      $Id: make_v_cback.pl 2238 2007-10-07 19:14:55Z mbarbon $
-## Copyright:   (c) 2007 Mattia Barbon
+## RCS-ID:      $Id: make_v_cback.pl 3003 2011-02-13 13:05:48Z mbarbon $
+## Copyright:   (c) 2007, 2011 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -22,6 +22,9 @@ my @macros =
      DEF_V_CBACK_BOOL__INT
      DEF_V_CBACK_BOOL__INT_pure
 
+     DEC_V_CBACK_BOOL__WXVARIANT_UINT_UINT
+     DEF_V_CBACK_BOOL__WXVARIANT_UINT_UINT_pure
+
      DEC_V_CBACK_BOOL__SIZET
      DEF_V_CBACK_BOOL__SIZET
      DEF_V_CBACK_BOOL__SIZET_pure
@@ -67,10 +70,20 @@ my @macros =
      DEF_V_CBACK_LONG__INT_INT_const
      DEF_V_CBACK_LONG__INT_INT_const_pure
 
+     DEC_V_CBACK_UINT__VOID
+     DEC_V_CBACK_UINT__VOID_const
+     DEF_V_CBACK_UINT__VOID
+     DEF_V_CBACK_UINT__VOID_const
+     DEF_V_CBACK_UINT__VOID_pure
+     DEF_V_CBACK_UINT__VOID_const_pure
+
      DEC_V_CBACK_VOID__INT_INT_LONG
      DEF_V_CBACK_VOID__INT_INT_LONG
      DEF_V_CBACK_VOID__INT_INT_LONG_pure
 
+     DEC_V_CBACK_VOID__mWXVARIANT_UINT_UINT_const
+     DEF_V_CBACK_VOID__mWXVARIANT_UINT_UINT_const_pure
+
      DEC_V_CBACK_VOID__SIZET_SIZET_const
      DEF_V_CBACK_VOID__SIZET_SIZET_const
 
@@ -87,6 +100,14 @@ my @macros =
 
      DEC_V_CBACK_WXSTRING__WXSTRING
      DEF_V_CBACK_WXSTRING__WXSTRING
+
+     DEC_V_CBACK_WXSTRING__UINT
+     DEC_V_CBACK_WXSTRING__UINT_const
+     DEF_V_CBACK_WXSTRING__UINT
+     DEF_V_CBACK_WXSTRING__UINT_const_pure
+
+     DEC_V_CBACK_WXGRIDATTR__INT_INT_WXATTRKIND
+     DEF_V_CBACK_WXGRIDATTR__INT_INT_WXATTRKIND
      );
 my %type_map =
   ( BOOL    => [ 'bool',    'SvTRUE( ret )', 'return false',
@@ -97,6 +118,8 @@ my %type_map =
                  'long p%d', 'l', 'p%d', 'p%d' ],
     INT     => [ 'int',     'SvIV( ret )', 'return 0',
                  'int p%d', 'i', 'p%d', 'p%d' ],
+    UINT    => [ 'unsigned int', 'SvUV( ret )', 'return 0',
+                 'unsigned int p%d', 'I', 'p%d', 'p%d' ],
     WXCOORD => [ 'wxCoord', 'SvIV( ret )', 'return 0',
                  'wxCoord p%d', 'l', 'p%d', 'p%d' ],
     DOUBLE  => [ 'double',  'SvNV( ret )', 'return 0.0', ],
@@ -104,6 +127,14 @@ my %type_map =
                  ],
     WXSTRING=> [ 'wxString','wxPli_sv_2_wxString( aTHX_ ret )', 'return wxEmptyString',
                  'const wxString& p%d', 'P', '&p%d', 'p%d' ],
+    WXVARIANT=> [ 'wxVariant','wxPli_sv_2_wxvariant( aTHX_ ret )', 'return wxVariant()',
+                 'const wxVariant& p%d', 'q', '&p%d, "Wx::Variant"', 'p%d' ],
+    mWXVARIANT=> [ 'wxVariant','wxPli_sv_2_wxvariant( aTHX_ ret )', 'return wxVariant()',
+                 'wxVariant& p%d', 'q', '&p%d, "Wx::Variant"', 'p%d' ],
+    WXGRIDATTR=> [ 'wxGridCellAttr*', '(wxGridCellAttr*)wxPli_sv_2_object( aTHX_ ret, "Wx::GridCellAttr" )', 'return NULL',
+                   'wxGridCellAttr* p%d', 'q', 'p%d, "Wx::GridCellAttr"', 'p%d' ],
+    WXATTRKIND=> [ 'wxGridCellAttr::wxAttrKind', 'SvIV( ret )', 'return 0',
+                   'wxGridCellAttr::wxAttrKind p%d', 'i', 'p%d', 'p%d' ],
     );
 my %const_map =
   ( 0       => 'wxPli_NOCONST',
